@@ -1,5 +1,3 @@
-import copy
-import datetime
 import json
 import logging
 import os
@@ -55,11 +53,11 @@ class Prepuller(object):
                 slashes = image.count("/")
                 if slashes == 0:
                     image = "library/" + image
+                if slashes == 1:
+                    image = "registry.hub.docker.com/" + image
             self.images.append(image)
         # Cheap way to deduplicate lists
         self.images = list(set(self.images))
-        if self.images:
-            self.images.sort()
         # Not portable to non-Unixy systems.
         if self.args.timeout >= 0:
             self.logger.debug("Setting timeout to %d s." % self.args.timeout)
@@ -125,9 +123,7 @@ class Prepuller(object):
                     releases=self.args.releases,
                     experimentals=self.args.experimentals,
                     recommended=self.args.recommended,
-                    json=True,
                     insecure=self.args.insecure,
-                    sort_field=self.args.sort,
                     cachefile=self.cachefile,
                     debug=self.args.debug,
                     username=self.args.username,
@@ -140,29 +136,29 @@ class Prepuller(object):
                     )
                 else:
                     self.logger.debug("Scanning Docker repo for images")
-                self.repo.scan()
+                repo = self.repo
+                repo.scan()
                 self.logger.debug(
                     "Scan Data: "
-                    + json.dumps(self.repo.data, sort_keys=True, indent=4)
+                    + json.dumps(self.repo.data, sort_keys=True, indent=4,
+                                 default=repo._serialize_datetime_and_semver)
                 )
                 scan_imgs = []
                 sections = []
                 if self.args.recommended:
                     sections.extend(["recommended"])
-                sections.extend(["experimental", "daily", "weekly", "release"])
+                sections.extend(["weekly", "daily", "experimental", "release"])
                 for section in sections:
-                    if section not in self.repo.data:
+                    if section not in repo.data:
                         continue
-                    for entry in self.repo.data[section]:
+                    for entry in repo.data[section]:
                         exhost = ""
                         if self.args.repo:
                             exhost = self.args.repo
                             if self.args.port:
                                 exhost += ":" + self.args.port
                         if exhost == "hub.docker.com":
-                            # We could change it to "index.docker.io" but
-                            #  leaving it empty works too.
-                            exhost = ""
+                            exhost = "registry.hub.docker.com"
                             if exhost and exhost[-1] != "/":
                                 exhost += "/"
                             scan_imgs.append(
