@@ -357,7 +357,11 @@ class RubinSpawner(MultiNamespacedKubeSpawner):
                         tag = cit
                         image = imgname + ":" + cit
             self.log.debug("Replacing image from options form: %s" % image)
-            self.image = image
+
+            if cfg.lab_repo_host == "hub.docker.com":
+                self.image = image
+            else:
+                self.image = cfg.lab_repo_host + "/" + image
             pod_env["JUPYTER_IMAGE_SPEC"] = image
             pod_env["JUPYTER_IMAGE"] = image
         # Set flag to clear .local if indicated
